/*
 * command_list.h: Command block class for pglatex_check and
 * pglatex_post, programs to compile LaTeX documents at
 * Project Gutenberg
 *
 * Version 1.1.0
 * Last Change: 08 June, 2008
 *
 *
 * Copyright (C) 2008
 *
 * Andrew D. Hwang (DP: adhere)
 * Department of Mathematics and Computer Science
 * College of the Holy Cross
 * Worcester, MA, 01610-2395, USA
 *
 *
 * pglatex is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * pglatex is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with pglatex; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef PGL_CMDLIST
#define PGL_CMDLIST

#include <list>

#include "typedefs.h"

class command;

class line;
// class file;

// A command_list stores a compile history to convert a LaTeX file to
// PDF; it can perform self-validation and run itself on a specified
// file.
class command_list {
public:
  // examine list of lines, look for first contiguous sequence of
  // recognized command strings
  // UPDATE constructor logic if command types change
  command_list(const std::list<line>&);

  ~command_list();

  // Return value: Our validation status (T/F)
  // Action: We comprise a list of commands, each of which can perform a
  //   "validate" operation (described in detail above). Pass "FFF" to our
  //   first command, and sequentially pass each command's validation status
  //   to the next command in our list; return the final command's status.
  // Remark: Return value is T iff our sequence of commands performs the
  //   conversions tex -> dvi -> ps -> pdf (or their equivalents, e.g.,
  //   dvipdfm = dvips + ps2pdf) in order.
  bool validate(FILENAME fileroot) const;

  // Input: Root name of a file
  // Return: 0 or first non-zero exit status
  // Action: Run our commands sequentially on the named file
  int process(FILENAME fileroot) const;

  //  void print(file& logfile, FILENAME) const;
  std::list<std::string> print(FILENAME fileroot, bool verbal=false) const;

private:
  std::list<command*> m_commands;

  // no copying
  command_list(const command_list&);
  command_list& operator= (const command_list&);
}; // end of command_list class
#endif /* PGL_CMDLIST */
