/*
 * input_file.h: LaTeX source file class for pglatex_check and
 * pglatex_post, programs to compile LaTeX documents at
 * Project Gutenberg
 *
 * Version 1.1.4
 * Last Change: 22 August, 2009
 *
 *
 * Copyright (C) 2008, 2009
 *
 * Andrew D. Hwang (DP: adhere)
 * Department of Mathematics and Computer Science
 * College of the Holy Cross
 * Worcester, MA, 01610-2395, USA
 *
 *
 * pglatex is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * pglatex is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with pglatex; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef PGL_INFILE
#define PGL_INFILE

#include <list>
#include <string>

#include "typedefs.h"
#include "line.h"

// read-only abstraction in memory of file created by PG posting program
// UPDATE constructor logic and class interface if stanza types change
class input_file {
public:
  // read named disk file, check for required stanzas and set separators
  input_file(FILENAME);

  std::list<line> header()   const; // PG header boilerplate text
  std::list<line> credits()  const; // PG credits line
  std::list<line> comments() const; // PPer's comments
  std::list<line> latex()    const; // entire latex file, incl. lprep config
  std::list<line> logfile()  const; // PPer's log file
  std::list<line> license()  const; // PG license text

  void print_warnings() const; // Warning messages (if any)

private:
  std::list<line> m_lines;

  // point to first line after end of corresponding stanza
  LINE m_header;
  LINE m_credits;
  LINE m_latex;
  LINE m_logfile;
  LINE m_license;

  // indices for PPer's comments
  LINE m_PP_begin;
  LINE m_PP_end;

  mutable std::list<line> m_warnings;

  // return successor of first line (starting from lp) matching f(*lp);
  // exit with error if m_lines.end() reached
  void seek_past(LINE& lp, bool f(const std::string&),
		 const std::string& err_msg) const;

  std::list<line> extract(CONST_LINE begin, CONST_LINE end) const;
}; // end of input_file class
#endif /* PGL_INFILE */
