/*
 * file.cc: Class representing a file line for pglatex_check and
 * pglatex_post, programs to compile LaTeX documents at
 * Project Gutenberg
 *
 * Version 1.1.0
 * Last Change: 08 June, 2008
 *
 *
 * Copyright (C) 2008
 *
 * Andrew D. Hwang (DP: adhere)
 * Department of Mathematics and Computer Science
 * College of the Holy Cross
 * Worcester, MA, 01610-2395, USA
 *
 *
 * pglatex is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * pglatex is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with pglatex; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include "utils.h"
#include "line.h"

using std::string;

// UPDATE constructor logic if placeholder types or criteria change
line::line(const string& data)
  : m_data(de_newline(data)), m_type(NONE)
{
  // Remove leading/trailing white space, "%"s, convert to lowercase
  string tmp(lowercase(de_comment(m_data)));

  // surrounded front and back by "***"?
  if (tmp.substr(0,3) == "***" && tmp.substr(tmp.size() - 3, 3) == "***")
    {
      tmp = de_star(tmp); // remove all surrounding asterisks, white space

      // guard against false positive from project title!
      if (tmp.substr(0, 11) != "start of th")
	{
	  // "license", etc., occurs in line
	  if (tmp.find("license") != string::npos ||
		   tmp.find("licence") != string::npos)
	    m_type =  LICENSELINE;

	  else if (tmp.find("boilerplate") != string::npos)
	    m_type = BOILERPLATE;

	  else if (tmp.find("credits") != string::npos)
	    m_type = CREDITSLINE;
	}
    }
  // otherwise we've set the type to NONE
}


// append DOS newline by default, *nix if requested
string line::print(bool DOS) const
{
  return DOS ? m_data + "\r\n" : m_data + "\n";
}

// classification
// Return value: type of placeholder (NONE, BOILERPLATE, CREDITS, or LICENSE)
const placeholder_type line::type() const
{
  return m_type;
}

const string& line::data() const
{
  return m_data;
}

// format by padding front and back with "%", specified total width
std::string line::format(unsigned int width) const
{
  string value("% " + m_data);
  if (value.size() < width)
    {
      string end_pad(width - value.size() - 1, ' ');
      value = value + end_pad + "%";
    }

  return value;
}
