/*
 * line.h: Class representing a file line for pglatex_check and
 * pglatex_post, programs to compile LaTeX documents at
 * Project Gutenberg
 *
 * Version 1.1.0
 * Last Change: 08 June, 2008
 *
 *
 * Copyright (C) 2008
 *
 * Andrew D. Hwang (DP: adhere)
 * Department of Mathematics and Computer Science
 * College of the Holy Cross
 * Worcester, MA, 01610-2395, USA
 *
 *
 * pglatex is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * pglatex is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with pglatex; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef PGL_LINE
#define PGL_LINE

#include <list>
#include <string>

#include "constants.h"

// abstraction of a line from a file
class line {
 public:
  // UPDATE constructor logic if placeholder types change
  line(const std::string&);  // strip newline, classify placeholder type

  std::string print(bool DOS=true) const; // append DOS newline by default

  // return data
  const placeholder_type type() const;
  const std::string& data() const;

  // format by padding front and back with "%", specified total width
  std::string format(unsigned int width) const;

 private:
  std::string m_data;
  placeholder_type m_type;
}; // end of line class

typedef std::list<line>::iterator LINE;
typedef std::list<line>::const_iterator CONST_LINE;

#endif /* PGL_LINE */
